# create-event-emitter

A simple abstraction for creating your own event-emitting objects. Uses the standard `EventEmitter` implementation in Node.js

## License

[WTFPL](http://www.wtfpl.net/txt/copying/) or [CC0](https://creativecommons.org/publicdomain/zero/1.0/), whichever you prefer. A donation and/or attribution are appreciated, but not required.

## Donate

Maintaining open-source projects takes a lot of time, and the more donations I receive, the more time I can dedicate to open-source. If this module is useful to you, consider [making a donation](http://cryto.net/~joepie91/donate.html)!

You can donate using Bitcoin, PayPal, Flattr, cash-in-mail, SEPA transfers, and pretty much anything else. Thank you!

## Contributing

Pull requests welcome. Please make sure your modifications are in line with the overall code style, and ensure that you're editing the files in `src/`, not those in `lib/`.

Build tool of choice is `gulp`; simply run `gulp` while developing, and it will watch for changes.

Be aware that by making a pull request, you agree to release your modifications under the licenses stated above.

## Usage

```javascript
const createEventEmitter = require("create-event-emitter");

let doorbell = createEventEmitter({
	ring: function ringDoorbell(noise = "RING RING!") {
		this.emit("ringing", noise);
	}
});

doorbell.on("ring", (noise) => {
	console.log(`Doorbell is ringing: ${noise}`);
});

doorbell.ring(); // Prints: "Doorbell is ringing: RING RING!"
```

## API

### createEventEmitter(properties)

Creates a new event-emitting object with the specified properties. The resulting `emitter` has the standard [EventEmitter API](https://nodejs.org/api/events.html#events_class_eventemitter).

* __properties__: The properties that the new event-emitting object should have. These are simply merged into the `emitter` object.

### emitter.emit(eventName, [... arguments])

Emits the specified event on the `emitter`, triggering the associated event handlers, if any. You'd usually call this from *within* a method on the `emitter`, as `this.emit`.

* __eventName__: The name of the event to emit/trigger.
* __... arguments__: The arguments to pass to the event handler. Any amount is allowed.

Note that this is part of the API of the standard Node.js EventEmitter, as documented [here](https://nodejs.org/api/events.html#events_emitter_emit_eventname_args).
